Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/htu21df_simpletest.py
    :caption: examples/htu21df_simpletest.py
    :lines: 5-

Resolution Setting
--------------------

Resolution setting

.. literalinclude:: ../examples/htu21df_resolution.py
    :caption: examples/htu21df_resolution.py
    :lines: 5-
